@@ -1,4 +1,6 @@
 import json
+
+from avenieca.config.broker import Broker
 from kafka import KafkaProducer
 
 
@@ -9,11 +11,11 @@ class Producer:
     :param config: configuration dictionary
     """
     def __init__(self,
-                 config: dict,
+                 config: Broker,
                  ):
         self.config = config
-        self.topic = config["topic"]
-        self.client = KafkaProducer(bootstrap_servers=config["bootstrap_servers"])
+        self.topic = config.sub_topic
+        self.client = KafkaProducer(bootstrap_servers=config.url)
 
     def send(self, data: dict):
         """
@@ -23,4 +25,3 @@ class Producer:
         json_object = json.dumps(data).encode("utf-8")
         result = self.client.send(self.topic, json_object)
         return result
-
